defmodule Nulla.AnnouncesTest do
  use Nulla.DataCase

  alias Nulla.Announces

  describe "announces" do
    alias Nulla.Announces.Announce

    import Nulla.ActorsFixtures
    import Nulla.NotesFixtures
    import Nulla.AnnouncesFixtures

    @invalid_attrs %{
      actor_id: nil,
      note_id: nil
    }

    test "list_announces/0 returns all announces" do
      announce = announce_fixture()
      assert Announces.list_announces() == [announce]
    end

    test "get_announce!/1 returns the announce with given id" do
      announce = announce_fixture()
      assert Announces.get_announce!(announce.id) == announce
    end

    test "create_announce/1 with valid data creates a announce" do
      actor = actor_fixture()
      note = note_fixture()

      valid_attrs = %{
        actor_id: actor.id,
        note_id: note.id
      }

      assert {:ok, %Announce{} = announce} = Announces.create_announce(valid_attrs)
      assert is_integer(announce.actor_id)
      assert is_integer(announce.note_id)
    end

    test "create_announce/1 with invalid data returns error changeset" do
      assert {:error, %Ecto.Changeset{}} = Announces.create_announce(@invalid_attrs)
    end

    test "update_announce/2 with valid data updates the announce" do
      actor = actor_fixture()
      note = note_fixture()
      announce = announce_fixture()

      update_attrs = %{
        actor_id: actor.id,
        note_id: note.id
      }

      assert {:ok, %Announce{} = announce} = Announces.update_announce(announce, update_attrs)
      assert is_integer(announce.actor_id)
      assert is_integer(announce.note_id)
    end

    test "update_announce/2 with invalid data returns error changeset" do
      announce = announce_fixture()
      assert {:error, %Ecto.Changeset{}} = Announces.update_announce(announce, @invalid_attrs)
      assert announce == Announces.get_announce!(announce.id)
    end

    test "delete_announce/1 deletes the announce" do
      announce = announce_fixture()
      assert {:ok, %Announce{}} = Announces.delete_announce(announce)
      assert_raise Ecto.NoResultsError, fn -> Announces.get_announce!(announce.id) end
    end

    test "change_announce/1 returns a announce changeset" do
      announce = announce_fixture()
      assert %Ecto.Changeset{} = Announces.change_announce(announce)
    end
  end
end
