defmodule Nulla.LikesTest do
  use Nulla.DataCase

  alias Nulla.Likes

  describe "likes" do
    alias Nulla.Likes.Like

    import Nulla.ActorsFixtures
    import Nulla.NotesFixtures
    import Nulla.LikesFixtures

    @invalid_attrs %{
      actor_id: nil,
      note_id: nil
    }

    test "list_likes/0 returns all likes" do
      like = like_fixture()
      assert Likes.list_likes() == [like]
    end

    test "get_like!/1 returns the like with given id" do
      like = like_fixture()
      assert Likes.get_like!(like.id) == like
    end

    test "create_like/1 with valid data creates a like" do
      actor = actor_fixture()
      note = note_fixture()

      valid_attrs = %{
        actor_id: actor.id,
        note_id: note.id
      }

      assert {:ok, %Like{} = like} = Likes.create_like(valid_attrs)
      assert is_integer(like.actor_id)
      assert is_integer(like.note_id)
    end

    test "create_like/1 with invalid data returns error changeset" do
      assert {:error, %Ecto.Changeset{}} = Likes.create_like(@invalid_attrs)
    end

    test "update_like/2 with valid data updates the like" do
      actor = actor_fixture()
      note = note_fixture()
      like = like_fixture()

      update_attrs = %{
        actor_id: actor.id,
        note_id: note.id
      }

      assert {:ok, %Like{} = like} = Likes.update_like(like, update_attrs)
      assert is_integer(like.actor_id)
      assert is_integer(like.note_id)
    end

    test "update_like/2 with invalid data returns error changeset" do
      like = like_fixture()
      assert {:error, %Ecto.Changeset{}} = Likes.update_like(like, @invalid_attrs)
      assert like == Likes.get_like!(like.id)
    end

    test "delete_like/1 deletes the like" do
      like = like_fixture()
      assert {:ok, %Like{}} = Likes.delete_like(like)
      assert_raise Ecto.NoResultsError, fn -> Likes.get_like!(like.id) end
    end

    test "change_like/1 returns a like changeset" do
      like = like_fixture()
      assert %Ecto.Changeset{} = Likes.change_like(like)
    end
  end
end
